@@ -16,7 +16,6 @@
   You should have received a copy of the GNU General Public License
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include <cctype>
 
 #include "modified-font-metric.hh"
 #include "pango-font.hh"
@@ -25,6 +24,8 @@
 #include "main.hh"
 #include "program-option.hh"
 
+#include <cctype>
+
 using std::string;
 
 Preinit_Modified_font_metric::Preinit_Modified_font_metric ()
@@ -42,7 +43,7 @@ Modified_font_metric::Modified_font_metric (Font_metric *fm,
   Real total_mag = magnification * scm_to_double (scm_cdr (desc));
   assert (total_mag);
 
-  description_ = scm_cons (scm_car (desc), scm_from_double (total_mag));
+  description_ = scm_cons (scm_car (desc), to_scm (total_mag));
   orig_ = fm;
 }
 
